unit prog_acq;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Buttons, StdCtrls, ComCtrls, ExtCtrls;

type
  TfmProgAcq = class(TForm)
    Panel1: TPanel;
    btnCancel: TBitBtn;
    btnOK: TBitBtn;
    BeginDate: TDateTimePicker;
    BeginHour: TDateTimePicker;
    EndDate: TDateTimePicker;
    EndHour: TDateTimePicker;
    ListeProgAcq: TListBox;
    Label1: TLabel;
    Label2: TLabel;
    btnNettoyer: TSpeedButton;
    btnModifier: TSpeedButton;
    btnDelProgDate: TSpeedButton;
    btnInsProgDate: TSpeedButton;
    btnAddProgDate: TSpeedButton;
    procedure FormCreate(Sender: TObject);
    procedure btnAddProgDateClick(Sender: TObject);
    procedure btnDelProgDateClick(Sender: TObject);
    procedure btnOKClick(Sender: TObject);
    procedure btnInsProgDateClick(Sender: TObject);
    procedure BeginDateChange(Sender: TObject);
    procedure btnNettoyerClick(Sender: TObject);
    procedure ListeProgAcqDblClick(Sender: TObject);
    procedure btnModifierClick(Sender: TObject);
  private
    { Dclarations prives }
    procedure DelElapsedEndDate;
  public
    { Dclarations publiques }
  end;

const
  CR = #13;
  msgNoProgLine = '<Aucun demande d''acquisition programme>';
  msgBeforeDelete = 'Les lements slectionns vont tre supprims.' + CR + 'Continuer ?';

var
  fmProgAcq: TfmProgAcq;

implementation

uses
  Main;
  
{$R *.DFM}

procedure TfmProgAcq.FormCreate(Sender: TObject);
begin
  BeginDate.date := now;
  EndDate.date := now;
  BeginHour.time := now;
  EndHour.time := now;
  ListeProgAcq.items.add(msgNoProgLine);
  if fileExists(CheminApp + 'prog_acq.dat') then
    ListeProgAcq.items.LoadFromFile(CheminApp + 'prog_acq.dat');
end;

procedure TfmProgAcq.btnDelProgDateClick(Sender: TObject);
var
  i: integer;
begin
  with ListeProgAcq do begin
    if selCount = 0 then exit;
    if ((items.Count = 1) and (items[0] = msgNoProgLine)) then exit;
    if messageDlg(msgBeforeDelete, mtConfirmation, [mbYes, mbNo], 0) <> mrYes then exit;
    for i := items.count - 1 downTo 0 do begin
      if selected[i] then items.delete(i);
      if items.count = 0 then items.add(msgNoProgLine);
    end;
  end;
end;

procedure TfmProgAcq.btnAddProgDateClick(Sender: TObject);
var
  sBegin, sEnd: string;
begin
  sBegin := 'Dbut=' + dateToStr(BeginDate.date) + '-' + timeToStr(BeginHour.time);
  sEnd := 'Fin=' + dateToStr(EndDate.date) + '-' + timeToStr(EndHour.time);
  with ListeProgAcq do begin
    multiSelect := false;
    if ((items.Count = 1) and (items[0] = msgNoProgLine)) then
      items[0] := sBegin + '; ' + sEnd + ';'
    else
      items.add(sBegin + '; ' + sEnd + ';');
    itemIndex := items.count - 1;
    multiSelect := true;
  end;
end;

procedure TfmProgAcq.btnInsProgDateClick(Sender: TObject);
var
  sBegin, sEnd: string;
  idx: integer;
begin
  sBegin := 'Dbut=' + dateToStr(BeginDate.date) + '-' + timeToStr(BeginHour.time);
  sEnd := 'Fin=' + dateToStr(EndDate.date) + '-' + timeToStr(EndHour.time);
  with ListeProgAcq do begin
    idx := itemIndex;
    if idx = -1 then idx := items.count - 1;
    multiSelect := false;
    if ((items.Count = 1) and (items[0] = msgNoProgLine)) then
      items[0] := sBegin + '; ' + sEnd + ';'
    else
    items.insert(idx, sBegin + '; ' + sEnd + ';');
    multiSelect := true;
    selected[idx+1] := true;
  end;
end;

procedure TfmProgAcq.btnOKClick(Sender: TObject);
begin
  try
    ListeProgAcq.items.SaveToFile(CheminApp + 'prog_acq.dat');
  except
  end;
end;

procedure TfmProgAcq.BeginDateChange(Sender: TObject);
begin
  EndDate.date := BeginDate.date;
end;

procedure TfmProgAcq.btnNettoyerClick(Sender: TObject);
begin
  DelElapsedEndDate;
end;

procedure TfmProgAcq.DelElapsedEndDate;
var
  i: integer;
  s: string;
  fin: TDateTime;
begin
  if ListeProgAcq.items.count = 0 then exit;
  for i := ListeProgAcq.items.count - 1 downTo 0 do begin
    s := ListeProgAcq.items[i];
    fin := strToDateTime(copy(s, 32, 10) + ' ' + copy(s, 43, 8));
    if now > fin then ListeProgAcq.items.delete(i);
  end;
end;

procedure TfmProgAcq.ListeProgAcqDblClick(Sender: TObject);
var
  s: string;
  sBeginDate, sEndDate: TDate;
  sBeginTime, sEndTime: TTime;
begin
  s := ListeProgAcq.items[ListeProgAcq.itemIndex];
  sBeginDate := strToDate(copy(s, 7, 10));
  sEndDate := strToDate(copy(s, 32, 10));
  sBeginTime := strToTime(copy(s, 18, 8));
  sEndTime := strToTime(copy(s, 43, 8));
  BeginDate.date := sBeginDate;
  EndDate.date := sEndDate;
  BeginHour.time := sBeginTime;
  EndHour.time := sEndTime;
end;

procedure TfmProgAcq.btnModifierClick(Sender: TObject);
var
  sBegin, sEnd: string;
  idx: integer;
begin
  with ListeProgAcq do begin
    idx := itemIndex;
    if idx = -1 then exit;
    sBegin := 'Dbut=' + dateToStr(BeginDate.date) + '-' + timeToStr(BeginHour.time);
    sEnd := 'Fin=' + dateToStr(EndDate.date) + '-' + timeToStr(EndHour.time);
    items[idx] := sBegin + '; ' + sEnd + ';';
    selected[idx] := true;
  end;
end;

end.
