unit acqType;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Buttons, ExtCtrls, ComCtrls, IniFiles;

type
  TFmChoixTypeAcq = class(TForm)
    btnOK: TBitBtn;
    btnCancel: TBitBtn;
    ListView1: TListView;
    ImageList1: TImageList;
    Bevel1: TBevel;
    btnNew: TSpeedButton;
    btnDelete: TSpeedButton;
    procedure btnOKClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btnCancelClick(Sender: TObject);
    procedure btnNewClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
  private
    { Dclarations prives }
     procedure PopulateListView;
  public
    { Dclarations publiques }
  end;

var
  FmChoixTypeAcq: TFmChoixTypeAcq;

implementation

uses
  main;
{$R *.DFM}

procedure TFmChoixTypeAcq.btnOKClick(Sender: TObject);
var
  sMsg: string;
  i: integer;
  lst: TStringList;
  s: string;
  AllAcq: boolean;
begin
  if listView1.selected = nil then begin
    sMsg := 'Aucun type d''acquisition slectionn.';
    messageDlg(sMsg, mtInformation, [mbOK], 0);
    exit;
  end;

  // vrification droit du type d'acquisition
  if listView1.selected.Index <> 0 then begin
    try
      lst := TStringList.create;
      for i := 1 to ParamCount do begin
        s := ParamStr(i);
        lst.add(s);
      end;
      AllAcq := (lst.IndexOf('AllAcq') > -1);
    finally
      lst.Free;
    end;
    if not AllAcq then begin
      sMsg := 'Type d''acquisition non support pour le moment.';
      messageDlg(sMsg, mtInformation, [mbOK], 0);
      with listView1 do begin
        setFocus;
        selected := items[0];
      end;
      exit;
    end;
  end;

  modalResult := mrOK;
  MainTitle := listView1.selected.caption;
end;

procedure TFmChoixTypeAcq.FormCreate(Sender: TObject);
begin
  PopulateListView;
  if listView1.Items.Count > 0 then listView1.Selected := listView1.Items[0];
end;

procedure TFmChoixTypeAcq.PopulateListView;
var
  i: integer;
  s: string;
  newItem: TListItem;
  ini: TIniFile;
  lst: TStringList;
begin
  try
    ini := TIniFile.Create(AppIniFile);
    lst := TStringList.create;
    ini.ReadSections(lst);
    for i := 0 to lst.count - 1 do begin
      if copy(lst[i], 1, 8) = 'Options-' then begin
        s := copy(lst[i], 9, 255);
        newItem := listView1.Items.Add;
        newItem.caption := s;
        newItem.ImageIndex := 0;
      end;
    end;
  finally
    ini.free;
    lst.free;
  end;
end;

procedure TFmChoixTypeAcq.btnCancelClick(Sender: TObject);
begin
  if MainTitle = '' then begin
    application.onDeactivate := nil;
    application.terminate;
  end;
  close;
end;

procedure TFmChoixTypeAcq.btnNewClick(Sender: TObject);
var
  ini: TIniFile;
  newItem: TListItem;
  i: integer;
  s, section: string;
begin
  s := 'Nouveau type acquisition';
  if not inputQuery('Nouveau', 'Nouveau type acquisition', s) then exit;

  with listView1 do begin
    for i := 0 to items.count - 1 do begin
      if items[i].caption = s then begin
        showMessage('Le type que vous voulez crer existe dj.');
        exit;
      end;
    end;
    newItem := listView1.Items.Add;
    newItem.caption := s;
    newItem.ImageIndex := 0;
    selected := newItem;
  end;

  section := 'Options-' + s;
  try
    ini := TIniFile.Create(AppIniFile);
    ini.WriteInteger(section, 'CANInputNum', 1);
    ini.WriteBool('General', 'PrintColor', false);
    ini.WriteInteger(section, 'TimerInterval', 1000);
    ini.WriteBool(section, 'EOCControl', true);
    ini.WriteBool(section, 'RAZAfterAcq', true);
    ini.WriteBool(section, 'ShowAverageTrace', false);
    ini.WriteBool(section, 'AcquisitionMode', true);
    ini.WriteString('Options-' + s, 'DataDir', cheminApp + 'data\divers\');
    ini.WriteBool(section, 'AlwaysDataRec', false);
    ini.WriteString(section, 'BaseUnit', 'Unit');
    ini.WriteString(section, 'ScreenUnit', 'Unit');
    ini.WriteString(section, 'FactorUnit', '1');
    ini.WriteString(section, 'AverageNum', '100');
    ini.WriteString(section, 'MinUserValue', '0');
    ini.WriteString(section, 'MaxUserValue', '10');
    ini.WriteString(section, 'MinGraphUserValue', '0');
    ini.WriteString(section, 'MaxGraphUserValue', '10');
    ini.WriteString(section, 'HorizontalDivisions', '4');
    ini.WriteString(section, 'VerticalDivisions', '0');
    ini.WriteString(section, 'MinThreshold', '0');
    ini.WriteString(section, 'MaxThreshold', '0');
    ini.WriteInteger(section, 'BackGroundColor', clBlack);
    ini.WriteInteger(section, 'GridColor', clSilver);
    ini.WriteInteger(section, 'TraceColor', clAqua);
    ini.WriteInteger(section, 'AverageTraceColor', clYellow);
    ini.WriteInteger(section, 'CursorColor', clLime);
    ini.WriteBool(section, 'LimitOverGraph', true);
    ini.WriteBool('General', 'ShowThresholds', true);
    ini.WriteInteger('General', 'ComNum', 1);
    ini.WriteString('General', 'MaxGauge', '30');
    ini.WriteString('General', 'FreeDiskLimit', '50');
    ini.WriteString(section, 'DefaultValue', '0');
  finally
    ini.Free;
  end;
end;

procedure TFmChoixTypeAcq.btnDeleteClick(Sender: TObject);
var
  sMsg: string;
  s: string;
  ini: TIniFile;
begin
  if listView1.selected = nil then exit;
  s := listView1.selected.caption;
  sMsg := 'Supprimer vraiment "' + s + '" ?' + CRLF +
          'Vous ne pourrez pas le rcuprer par la suite !';
  if messageDlg(sMsg, mtConfirmation, [mbYes, mbNo], 0) <> mrYes then exit;
  listView1.selected.delete;
  try
    ini := TIniFile.Create(AppIniFile);
    ini.EraseSection('Options-' + s);
  finally
    ini.Free;
  end;
  btnCancel.enabled := false;
end;

procedure TFmChoixTypeAcq.FormActivate(Sender: TObject);
begin
  btnCancel.enabled := true;
end;

end.
